@@ -63,7 +63,7 @@ class NewRelicAlerts(object):
           if condition[k] != v:
             self.newrelic.delete_policy_alert_condition(condition['id'])
             policy.remote_conditions = self.newrelic.get_policy_alert_conditions(policy.id)
-            logger.info("delete condition {} from policy {}. ".format(condition['name'], policy.name) + \
+            logger.info("delete condition {} from policy {}. ".format(condition['name'], policy.name) +
                         "current value differs from config")
             break
 
@@ -71,10 +71,12 @@ class NewRelicAlerts(object):
 
   def create_infra_alert_conditions(self, policy):
     # Create alert conditions for policies
-    for key, value in policy.config_conditions.items():
-      if not any(condition['name'] == key for condition in policy.remote_conditions):
-        self.newrelic.create_alert_condition(policy.config_conditions[key])
-        logger.info("create condition {} for policy {}".format(key, policy.name))
+    remote_conditions = set([condition['name'] for condition in policy.remote_conditions])
+    conditions_to_create = set(policy.config_conditions.keys()).difference(remote_conditions)
+
+    for key in conditions_to_create:
+      self.newrelic.create_alert_condition(policy.config_conditions[key])
+      logger.info("create condition {} for policy {}".format(key, policy.name))
 
   def update_cloudfront_policy(self):
     # Update Cloudfront alert policies
@@ -112,16 +114,25 @@ class NewRelicAlerts(object):
       'type': 'infra_metric',
     }
 
-    policy = self.populate_alert_policy_values('cloudfront')
+    policy = AlertPolicy(env=self.context.env, service='cloudfront')
+
+    # Create cloudfront alert policy if it doesn't already exist
+    if not self.newrelic.alert_policy_exists(policy.name):
+      self.newrelic.create_alert_policy(policy.name)
+      logger.info("create alert policy {}".format(policy.name))
+
+    self.populate_alert_policy_values(policy)
+    self.add_alert_policy_to_notification_channels(policy)
+
     conditions = {}
     for id, alias in queue:
-      conditions['cloudfront-{}-{}'.format(id, '4xxErrorRate')] = meta(
-        '4xxErrorRate', 10, id, '4xx Average {}'.format(alias), policy.id)
-      conditions['cloudfront-{}-{}'.format(id, '5xxErrorRate')] = meta(
-        '5xxErrorRate', 5, id, '5xx Average {}'.format(alias), policy.id)
+      conditions['4xx Average {}'.format(alias)] = meta(
+        'error4xxErrorRate', 10, id, '4xx Average {}'.format(alias), policy.id)
+      conditions['5xx Average {}'.format(alias)] = meta(
+        'error5xxErrorRate', 5, id, '5xx Average {}'.format(alias), policy.id)
 
     policy.config_conditions = deepcopy(conditions)
-
+    # Infra alert conditions
     policy = self.delete_conditions_not_matching_config_values(policy)
     self.create_infra_alert_conditions(policy)
 
